@@ -80,7 +80,7 @@
 
 void KSudoku::onCompleted(bool isCorrect, const QTime& required, bool withHelp) {
 	if(!isCorrect) {
-		KMessageBox::information(this, i18n("Sorry the solution you entered is not correct.\nIf you want to see error check Options->Guided mode please."));
+		KMessageBox::information(this, i18n("Sorry, your solution contains mistakes.\n\nEnable \"Show errors\" in the settings to highlight them."));
 		return;
 	}
 
@@ -92,7 +92,7 @@ void KSudoku::onCompleted(bool isCorrect, const QTime& required, bool withHelp)
 	if(withHelp)
 		msg = i18n("Congratulations! You made it in %1 minutes and %2 seconds. With some tricks.", mins, secs);
 	else
-		msg = i18n("Congratulations!!!! You made it in %1 minutes and %2 seconds.", mins, secs);
+		msg = i18n("Congratulations! You made it in %1 minutes and %2 seconds.", mins, secs);
 
 	KMessageBox::information(this, msg);
 
@@ -727,7 +727,7 @@ void KSudoku::optionsPreferences()
 
 	SymbolConfig* symbolConfig = new SymbolConfig(&m_symbols);
 	dialog->addPage(symbolConfig, i18n("Symbol Themes"), "games-config-theme");
-
+        dialog->setHelp(QString(),"ksudoku");
 	connect(dialog, SIGNAL(settingsChanged(const QString&)), SLOT(settingsChanged()));
     dialog->show();
 }
